package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.30.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.30.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,``@$!````:"0```````!``````````)##````
M`````P```$``.``)`$``&@`9``8````$````0`````````!``````````$``
M````````^`$```````#X`0````````@``````````P````0````X`@``````
M`#@"````````.`(````````/``````````\``````````0`````````!````
M!0```````````````````````````````````&"A````````8*$`````````
M0`````````$````&````H+T```````"@_0```````*#]````````Z`0`````
M```8%0````````!``````````@````8```"PO0```````+#]````````L/T`
M``````!0`@```````%`"````````"``````````$````!````$@"````````
M2`(```````!(`@```````$0`````````1``````````$`````````%#E=&0$
M````%*$````````4H0```````!2A````````%``````````4``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````$`````````!2Y71D!````*"]````````H/T```````"@_0``
M`````&`"````````8`(````````!`````````"]L:6(V-"]L9"YS;RXQ```$
M````$`````$```!'3E4```````0````/``````````0````4`````P```$=.
M50`^H55(-C$2]9W</S&V`+;ONA?L8@````!A````:@``````````````6P``
M``L``````````````#<``````````````"D```!$`````````!8````M````
M90`````````[````4P```%0```!&````8````&<````Y````-```````````
M````'P```%T```!%``````````````!/````7@```$,``````````````&D`
M```R`````````%``````````%0`````````@````80```%(````G````````
M`$````!C`````````#@````C``````````````!<````3@```$(```!,````
M```````````9`````````$D`````````````````````````-0```#H````H
M````'@```&@````F``````````````!B````(@```$$```!'````5@```#8`
M```_`````````$H```````````````````!D````5P````````!+````60``
M`$@```!-````,`````<`````````````````````````````````````````
M````````````````````````````````"0````````````````````T`````
M````````````````````````````````````````````````````````````
M```2```````````````;````6````````````````````!0````*````````
M`!T`````````*@````````````````````\````K``````````````!F````
M%P``````````````#```````````````&@`````````8`````````#,````Q
M`````````%$````]````6@`````````\````+@```"P`````````)0```!,`
M````````$0``````````````50````X``````````````"0`````````````
M`!P````````````````````A```````````````^````+P```!``````````
M```````````````````````````(`````````%\``````````````!$```!1
M````!`````@````@$!``!4`$@"@```2`A@"$@@D```D@!`B(H!!%N@`""```
M``!1````5````%<```!8`````````%\```!@````8@```&,```!E````````
M`&8```!G````:0``````````````;L7?'\[>1RUK?YI\+L6;MM1DU'PA_^0.
MV7%8'.)'Q@&R`8MOK$OCP$+ZUX?"Y3\LNN.2?/NA;&!GK\QF0D75[(D'<-,-
M%.*>,F+;[=O-XYX5C"7,?ZF<F^"G`@IK&IY0H^#[20``````````````````
M```````````````````#``T`$"(````````````````````````#``X`H&(`
M```````````````````````#`!``**$````````````````````````#`!0`
M```!```````````````````````#`!8`@`(!```````````````````````#
M`!<`B`(!`````````````````/L!```2`````````````````````````&4#
M```1`````````````````````````/T````2````````````````````````
M`'("```2`````````````````````````"`"```2````````````````````
M`````(0````2`````````````````````````/(````1````````````````
M`````````(0!```2`````````````````````````-L"```2````````````
M`````````````'D"```2`````````````````````````)L!```2````````
M`````````````````/("```2`````````````````````````!,!```2````
M`````````````````````$,#```1`````````````````````````"$#```2
M`````````````````````````!L"```2`````````````````````````/,!
M```2`````````````````````````$0!```2````````````````````````
M`*4````2`````````````````````````#0!```2````````````````````
M`````"8!```2`````````````````````````(X"```2````````````````
M`````````-(!```2`````````````````````````(<"```2````````````
M`````````````$("```2``````````````````````````P"```2````````
M`````````````````$L#```2`````````````````````````!$````@````
M`````````````````````.("```2`````````````````````````%<"```2
M`````````````````````````*(!```2`````````````````````````"T`
M```@`````````````````````````"@"```2````````````````````````
M`,H"```2`````````````````````````$(#```A````````````````````
M`````$<````2`````````````````````````*("```2````````````````
M`````````$$#```1`````````````````````````&0"```2````````````
M`````````````'0!```2`````````````````````````"@#```2````````
M`````````````````&0````2`````````````````````````.$````2````
M`````````````````````'4````2`````````````````````````"\#```2
M`````````````````````````,4````2``````````````````````````(!
M```2`````````````````````````!D#```2````````````````````````
M`&8!```2`````````````````````````.L"```2````````````````````
M`````$D"```2`````````````````````````.T!```2````````````````
M`````````%@!```2`````````````````````````&L"```2````````````
M`````````````%T"```2`````````````````````````-0"```1````````
M``````````````````<!```2`````````````````````````/P"```B````
M`````````````````````)`````2`````````````````````````$\"```2
M`````````````````````````(`"```2`````````````````````````(\!
M```2`````````````````````````+<"```2````````````````````````
M`)0"```2`````````````````````````!4$```2````````````````````
M`````.8!```2`````````````````````````-0````1````````````````
M``````````L#```2`````````````````````````$T!```2````````````
M`````````````%4````2`````````````````````````,("```2````````
M`````````````````#$"```2`````````````````````````*D"```2````
M`````````````````````+,````2`````````````````````````!X$```2
M``T`8$,```````"<`````````'8$```2``T`Z#8```````!T"````````#P#
M```2``T`$"(```````!8`@```````(4#```2``T`R"\````````$````````
M`+,#```2``T`8#\```````#\`P```````)P$```2``T`T"\```````!(`@``
M`````%P$```0`!<`B`(!`````````````````)8#```2``T`&#(````````T
M`````````,D#```2``T`0#4```````"8`````````"H$```1``X`H&(`````
M```$`````````#D$```2``T`<%L```````#(!````````$0$```2``T`&"X`
M```````\`````````'$$```0`!<`N!(!`````````````````(H$```2``T`
M`#8```````#D`````````.T#```2``T`4#(````````<`0```````(,$```0
M`!8`B`(!`````````````````*D$```1`!0`"``!```````(`````````*,#
M```2``T`@&(````````$`````````&$$```2``T`:"0```````"$````````
M`$P$```2``T`Z&$```````"4`````````&@$```2``T``%L```````!P````
M``````,$```2``T`V#4````````D`````````-<#```2``T`L"X````````4
M`0```````/D#```2``T`.&````````"P`0```````+,$```2``T`<#,`````
M``#0`0````````!L:6)P97)L+G-O+C4N,S``7TE435]D97)E9VES=&5R5$U#
M;&]N951A8FQE`%])5$U?<F5G:7-T97)434-L;VYE5&%B;&4`4&5R;%]S>7-?
M=&5R;0!097)L7W-Y<U]I;FET,P!097)L7V%T9F]R:U]L;V-K`'!E<FQ?8V]N
M<W1R=6-T`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?
M879?<VAI9G0`4&5R;%]S=E\R<'9?9FQA9W,`4&5R;%]S=E]S971P=FX`4$Q?
M9&]?=6YD=6UP`%!E<FQ?;F5W6%-?9FQA9W,`4$Q?=&AR7VME>0!P97)L7V9R
M964`4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T
M<'8`4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D
M97-T<G5C=`!097)L7V%V7V9E=&-H`&)O;W1?1'EN84QO861E<@!P97)L7W!A
M<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L;&]C`&QI8F1L+G-O+C(`
M;&EB;2YS;RXV`&QI8G!T:')E860N<V\N,`!P=&AR96%D7V=E='-P96-I9FEC
M`&]P96XV-`!C;&]S90!L<V5E:S8T`%]?97)R;F]?;&]C871I;VX`<F5A9`!L
M:6)C+G-O+C8`97AI=`!S=')N8VUP`&-L;W-E9&ER`%]?<W1A8VM?8VAK7V9A
M:6P`=6YL:6YK`&UK9&ER`')E86QL;V,`86)O<G0`;65M8VAR`&=E='!I9`!S
M=')D=7``<W1R=&]K`'-T<FQE;@!M96US970`<W1R<W1R`')M9&ER`%]?9G!R
M:6YT9E]C:&L`;65M8W!Y`%]?<W1R;F-P>5]C:&L`7U]L>'-T870V-`!O<&5N
M9&ER`%]?>'-T870V-`!S=&1E<G(`9V5T=6ED`')E861L:6YK`'-T<F-H<@!R
M96%D9&ER-C0`7U]C>&%?9FEN86QI>F4`7U]S<')I;G1F7V-H:P!M96UM;W9E
M`&%C8V5S<P!S=')C;7``7U]L:6)C7W-T87)T7VUA:6X`7U]E;G9I<F]N`%]?
M<F5G:7-T97)?871F;W)K`&QD+G-O+C$`7U]S=&%C:U]C:&M?9W5A<F0`;&EB
M8W)Y<'0N<V\N,0!P87)?8W5R<F5N=%]E>&5C`'!A<E]B87-E;F%M90!?7VQI
M8F-?8W-U7V9I;FD`6%-?26YT97)N86QS7U!!4E]"3T]4`'!A<E]E;G9?8VQE
M86X`<&%R7V-U<G)E;G1?97AE8U]P<F]C`'!A<E]D:7)N86UE`'-H85]F:6YA
M;`!G971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?8VQE86YU<`!?24]?
M<W1D:6Y?=7-E9`!S:&%?=7!D871E`'AS7VEN:70`7U]L:6)C7V-S=5]I;FET
M`%]?8G-S7W-T87)T`'-H85]I;FET`%]E;F0`<&%R7VUK=&UP9&ER`%]E9&%T
M80!P87)?<V5T=7!?;&EB<&%T:`!P87)?9FEN9'!R;V<`;7E?<&%R7W!L`'!A
M<E]I;FET7V5N=@!'3$E"0U\R+C(W`$=,24)#7S(N,@!'3$E"0U\R+C``````
M`````````````````@`#````!``$``````````0`!``$``0````$``0`!``%
M````````````!``"``0`!``"``0````$``0```````0`!``$````!``$``0`
M```$``````````0````$``0````$``0``@````0`!``$````!`````0`!```
M``0`!``$``4````$```````$``0`!`````$``0`!``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$```````$``0`1`@``$```
M`"````"'D98&```$`,`$`````````0`!`%T#```0````(````(>1E@8```,`
MP`0````````!``(`P@$``!``````````$FEI#0``!0#+!```$````!!I:0T`
M``(`U00```````"@_0````````,`````````P"4```````"H_0````````,`
M````````8"4````````(``$```````,`````````>&8````````(`@$`````
M``,`````````@&(```````!8`@$```````,`````````Z&$```````!X`@$`
M``````,`````````$"(```````"``@$```````,`````````@`(!````````
M`````````````````````````````````@$```````(````(````````````
M```0`@$```````(````-```````````````8`@$```````(````3````````
M```````@`@$```````(````4```````````````H`@$```````(````B````
M```````````P`@$```````(````D```````````````X`@$```````(````F
M``````````````!``@$```````(````N``````````````!(`@$```````(`
M```P``````````````!0`@$```````(````S``````````````!@`@$`````
M``(````^``````````````!H`@$```````(```!```````````````!P`@$`
M``````(```!)```````````````@``$```````4````'```````````````H
M``$```````4````)```````````````P``$```````4````*````````````
M```X``$```````4````+``````````````!```$```````4````,````````
M``````!(``$```````4````.``````````````!0``$```````4````/````
M``````````!8``$```````4````0``````````````!@``$```````4````1
M``````````````!H``$```````4````2``````````````!P``$```````4`
M```5``````````````!X``$```````4````6``````````````"```$`````
M``4````7``````````````"(``$```````4````8``````````````"0``$`
M``````4````9``````````````"8``$```````4````:``````````````"@
M``$```````4````;``````````````"H``$```````4````<````````````
M``"P``$```````4````=``````````````"X``$```````4````>````````
M``````#```$```````4````?``````````````#(``$```````4````@````
M``````````#0``$```````4````A``````````````#8``$```````4````C
M``````````````#@``$```````4````E``````````````#H``$```````4`
M```G``````````````#P``$```````4````H``````````````#X``$`````
M``4````J`````````````````0$```````4````K```````````````(`0$`
M``````4````M```````````````0`0$```````4````O```````````````8
M`0$```````4````Q```````````````@`0$```````4````R````````````
M```H`0$```````4````T```````````````P`0$```````4````U````````
M```````X`0$```````4````V``````````````!``0$```````4````W````
M``````````!(`0$```````4````X``````````````!0`0$```````4````Y
M``````````````!8`0$```````4````Z``````````````!@`0$```````4`
M```[``````````````!H`0$```````4````\``````````````!P`0$`````
M``4````]``````````````!X`0$```````4````_``````````````"``0$`
M``````4```!!``````````````"(`0$```````4```!"``````````````"0
M`0$```````4```!#``````````````"8`0$```````4```!$````````````
M``"@`0$```````4```!%``````````````"H`0$```````4```!&````````
M``````"P`0$```````4```!'``````````````"X`0$```````4```!(````
M``````````#``0$```````4```!*``````````````#(`0$```````4```!+
M``````````````#0`0$```````4```!,``````````````#8`0$```````4`
M``!-``````````````#@`0$```````4```!.``````````````#H`0$`````
M``4```!/``````````````#P`0$```````4```!0````````````````````
M`````,X!`!RMO1$`ST''**UA_P+,0<<"K05%`(PAP"C@`0!,SP$`'.\!QR@-
M```<X`$`3,\!`!SOX<8H#0``'.`!`$S/`0`<[\'&*`T``!S@`0!,SP$`'.^A
MQB@-```<X`$`3,\!`!SO@<8H#0``'.`!`$S/`0`<[V'&*`T``!S@`0!,SP$`
M'.]!QB@-```<X`$`3,\!`!SO(<8H#0``'.`!`$S/`0`<[P'&*`T``!S@`0!,
MSP$`'._AQ2@-```<X`$`3,\!`!SOP<4H#0``'.`!`$S/`0`<[Z'%*`T``!S@
M`0!,SP$`'.^!Q2@-```<X`$`3,\!`!SO8<4H#0``'.`!`$S/`0`<[T'%*`T`
M`!S@`0!,SP$`'.\AQ2@-```<X`$`3,\!`!SO`<4H#0``'.`!`$S/`0`<[^'$
M*`T``!S@`0!,SP$`'._!Q"@-```<X`$`3,\!`!SOH<0H#0``'.`!`$S/`0`<
M[X'$*`T``!S@`0!,SP$`'.]AQ"@-```<X`$`3,\!`!SO0<0H#0``'.`!`$S/
M`0`<[R'$*`T``!S@`0!,SP$`'.\!Q"@-```<X`$`3,\!`!SOX<,H#0``'.`!
M`$S/`0`<[\'#*`T``!S@`0!,SP$`'.^APR@-```<X`$`3,\!`!SO@<,H#0``
M'.`!`$S/`0`<[V'#*`T``!S@`0!,SP$`'.]!PR@-```<X`$`3,\!`!SO(<,H
M#0``'.`!`$S/`0`<[P'#*`T``!S@`0!,SP$`'._APB@-```<X`$`3,\!`!SO
MP<(H#0``'.`!`$S/`0`<[Z'"*`T``!S@`0!,SP$`'.^!PB@-```<X`$`3,\!
M`!SO8<(H#0``'.`!`$S/`0`<[T'"*`T``!S@`0!,SP$`'.\APB@-```<X`$`
M3,\!`!SO`<(H#0``'.`!`$S/`0`<[^'!*`T``!S@`0!,SP$`'._!P2@-```<
MX`$`3,\!`!SOH<$H#0``'.`!`$S/`0`<[X'!*`T``!S@`0!,SP$`'.]AP2@-
M```<X`$`3,\!`!SO0<$H#0``'.`!`$S/`0`<[R'!*`T``!S@`0!,SP$`'.\!
MP2@-```<X`$`3,\!`!SOX<`H#0``'.`!`$S/`0`<[\'`*`T``!S@`0!,SP$`
M'.^AP"@-```<X`$`3,\!`!SO@<`H#0``'.`!`$S/`0`<[V'`*`T``!S@`0!,
MSP$`'.]!P"@-```<X`$`3,\!`!SO(<`H#0``'.`!`$S/`0`<[P'`*`T``!S@
M`0!,SP$`'._A_R@-```<X`$`3,\!`!SOP?\H#0``'.`!`$QC@/X">"#!*=@!
M`!P8H_\H#`,`)F5`P"EF(,`I9!P`)68@P`)E0,`"9'#``FR@P"EA8,$I=T#!
M*7D`P2EZX,`I>\#`*?]O_U?&`0`<Q@#_*,4`%0#$`0`<A)#_*``<0%3,`0`<
MC`'`*(P!`"J`90%`]P$`'/?"P`+9`0`<.2/^*"0#`"3_[_Q7C&@2*HT`%0`D
M`P`DC`F``ZQI$BG_U_Q7C6@2*FP<`"2M!8`#C!6``HUH$BF$#4$`_XO^5VQ`
MP"C-`0`<K>'T`JT!`":.`0`F9AP`)(U`P"F.```GC0``'*T1S@*.```<SM'-
M`N\!`!SO<?X"CB#`*8U@P"D.$(`"[0$`'*U!_@*N`0`EY`$`)PT$@`*'`!4`
MTA"``J8Q`&2,(<`"40(5``T4@`(``$`#D`$`)J\=+0"N!8`"\.'_*<T!%0",
M(<`"T>G_7^0"`"92'BT`"``5`,8,@`(E```<I;#K`D#B_RG_._M7F0`5`("8
M`$#D`@`F>I#``O]7_5=%`Q4`A```'(00P`(`+`)4@(@`0.0"`";_R_I7_V?\
M5VV@P"@,`P`F)`,5`*RA`%QA8,$H=T#!*'@@P2AY`,$H>N#`*'O`P"AC@,$"
M(```3/\#_%?W`0`<]S+[`N0"`">`<`!`_V_\5]D!`!PY8_@H)`,`)/]_^U<L
M```4A+`0`(#$*"G_?_Y3Y`(`)O\7^U>9`!4`_V/_4_L!`!Q[`_H"9`,`)H`,
M`$``*!]4_VO_4T4#%0"$```<A'#[`@!\`51D`P`GGU#_0__C_U/_A_U7!`2`
M`O^O^E>)`!4`I`$`'`PPN`,,```6C`$``X0P##AE`,`H9B#``F,010!C$$$`
MIP$`'`P@MP,,```6C`$``^<P##BH`0`<#)"U`PP``!:,`0`#"#$,.&H`%0"A
M`0`<#%"V`PP``!:,`0`#(3`,."$``$RA`0`<#'"U`PP``!:,`0`#(3`,."$`
M`$P``$`#Q`$`'(2`[`+,`0`<C&'L`H09`%C,`0`<C)'T*(`-`$"``0!,``!`
M`R```$P``$`#Q`$`'(3`ZP+%`0`<I:#K`J60$0"E#$D`K/Q%`(65$`"E!$D`
MH!0`0,P!`!R,P?,H@`D`0(`!`$P@``!,``!``V/`_P)W```GUP$`'/>"]`+L
M`@`J82#`*8`U`$3,`0`<C+'S*(`=`$#,`0`<C.'S`H0!`";!`0`<(5#S*"$`
M`$S_4_]7#`2``NP"`"EA(,`H=P``)F-`P`(@``!,``!``_]C_U,``$`#8P#_
M`F'@P"EWP,`I>*#`*7F`P"EZ8,`I>T#`*7P@P"E]```G@`0!0,P!`!R,P?`H
MG0$`)J#W`$",```H@!T!0`WT@`(9`!4`C7D`7+<#`";@0@!`NP`5`)H`%0"X
M`Q4`'/2``@``0`/D`A4`)@,5`$4#%0#_5_A7@`P`1.QF`#B<:0!8&"/``A<#
M`";_WO]'8>#`*.0"%0!WP,`H>*#`*'F`P"AZ8,`H>T#`*'P@P"A]```F8P#!
M`B```$P``$`#C``5``[T@`*,!<`"C0$`**`)`$"N]?]?F9$1`#F#0`#_;_]3
M``!``QCW$0`8#TD`>`,`)6'@P"@Y!\`"]^80`.0"%0!WP,`H>*#`*'F`P"AZ
M8,`H>T#`*'P@P"A]```F8P#!`B```$QAX,`H%P`5`.0"%0!WP,`H>*#`*'F`
MP"AZ8,`H>T#`*'P@P"A]```F8P#!`B```$P9`!4`__/^4V,`_P)Z8,`IV@$`
M'%I#ZRA,`P`F=\#`*7B@P"EY@,`I8>#`*9@`%0!W$,`";"#`*=D!`!PY(^LH
MY0(5``0#%0#_8_Y7@#P`0"T#`"9L!``DC#4M`(TAP"B-`0`GO]W_0XPAP`*-
M(<`HC0$`)[_U_T?E`A4`!`,5`/\K_E>?S/]';2#`*$P#`":L(0!<8>#`*'?`
MP"AXH,`H>8#`*'I@P"AC`,$"(```3/\3^E<``$`#8X#^`GD`P2G9`0`<.8/H
M*'=`P2EX(,$I86#!*7K@P"E[P,`I?*#`*7V`P"E^8,`I?T#`*2X#`":M```H
M#/2``FX@P"FW`!4`F``5`*P)`%RW!,`"Y`(5`/^C]E>:`!4`91#``@0#%0#_
MB_U7FP`5`(!0`4#_A_97FA@!;'T$`"3<`0`<G"/G*+T/00`,`P`H@.$!0`WT
M@`*-V0%8#`,5``[T@`(`"`!0KA$`6(P%P`*-`0`HO_7_1XSA$0",@4``C0,`
M)D0+P`*$L!``O?40`/\[]E>D`P`G@(P!0(T#`"9L!``D#@,`*`0'P`*,-2T`
MC0$`)JX!`"G`,0!`#/2``LPI`%@.](`"``P`4```0`..&0!8A`3``HS\/RBM
M!<`"K`$`*9_M_T<.](`"K`7``JX!`"D``$`#]P;``NW^/RB,!<`"C?T_*;_Q
M_T<$`!4`;2#`*"P#`":L+0%<86#!*'=`P2AX(,$H>0#!*'K@P"A[P,`H?*#`
M*'V`P"A^8,`H?T#`*&.`P0(@``!,``!``_<&P`+L_C\H>P?``FS_/RF?K?]#
M]P;``NS^/RA[!\`";/\_*9_=_T?_E_]3``!``]P!`!R<(^(HGP,`)NP#`":`
MJ0!`[`,5``X`%0``"`!0K@$5`(PAP`*/`0`FS06``KL!%0#_[?]'S@V``L0-
M00#L`0`<C.'B`HT!`"2@/0!$#02``HT!`"7_\_17G@`5`(!$`$!]#T$`I@,5
M`.4#%0#_B_97G@,`)WY[+0#`(\`I>Q"`*?]+_E.%`!4`Y`,5`/\+]U>$`P`G
MG@`5`'T/00"?V/]'!/R_`O_K_E,``$`##``5`/]/_E,$0(`"&P`5`/^#_U/_
MA_=78T#\`GD@PRFY`0`<.6/>*"P#`"9AH,,I=H##*7=@PREX0,,I>@##*7O@
MPBE\P,(I?:#"*7Z`PBE_8,(I;"#"*8`0`$",```HF``5`(!%`$1M(,(H+`,`
M)JP]`5QAH,,H=H##*'=@PRAX0,,H>2##*'H`PRA[X,(H?,#"*'V@PBA^@,(H
M?V#"*&/`PP(@``!,_^/V5YH`%0"?N/]#>P``''NSW@)\```<G+/>`G8``!S6
MLMX"?R#``A[\OP)$`Q4`_]/S5X"L`$"73,`"90,5`.0"%0#_#_57G^3_0X4#
M%0#D`A4`___T5Y_4_T,$`Q4`_X/S5YT`%0#D`A4`_W?S5Z23$`"$@$``A`B`
M`O]W\U<&_+\"!02``ND"%0`(`Q4`QP(5`)T`%0#_&_97Y@,5`*4#%0`$`!4`
M_VOT5YX8`%AL&``D[@$`%(T``!2,N10`C3D`6*0#%0#_Z_-7I`,5`/_#]%=$
M`Q4`_ROS5Y]<_T=$`Q4`_Q_T5P0#%0#_E_-7_]/^4P``0`.D`Q4`_W?^5__/
M_U/_[_578T#]`G>`PBFW`0`<]P+8*.P"`"9X8,(IA0`5`)@`%0!F(,`"!``5
M`&&@PBEL(,(I_SOU5X`T`$1L&``D[@$`%(T``!2,N10`C0T`6$T!`!2-'0!<
M!0B``@0#%0#_K_)7A`1``@`(`%`$`!4`;2#"*.P"`":L&0!<8:#"*'>`PBAX
M8,(H8\#"`B```$S_7_578\#^`G<`P2EXX,`I[?__%;@!`!P8H]4H-P``%'G`
MP"EZH,`I82#!*7N`P"E\8,`I#`,`)F.T$`"Z`!4`[4*``\7__Q6MC1``I>"_
M`YD`%0`&_+\#I940`&0``!R$@-<";`@0)__G\E>$@$``!/P`9.U"@`.MC1``
M[/__%:RQ$`";_+\"C.T0`(SA/RBM`0`<K?'3*+P!`"2`B0!$8+<`0"P``!37
M__\5C$&``_?BOP.,C1``E]T0`&8#%0`%O(`"Y`(5`/^W\U>`B`!`A`,5`/\K
M\E=G`Q4`Y@(5`"4#%0#_"_-7;0@0)@P#`":LH0!<+0``%&.T$`!A(,$H=P#!
M*'C@P"AYP,`H>J#`*'N`P"A\8,`H8T#!`B```$P``$`#+```%-?__Q6,08`#
M]^*_`XR-$`";`!4`E]T0`&8#%0`%O(`"Y`(5`/\S\U>?@/]'A`,5`/^G\5=&
M`Q4`)0,5`/][\5?_@_]3K`$`'(R!T"B<`0`DA`,5`/^#\5=&`Q4`)0,5`/]7
M\5?_7_]3_\_S5ZP!`!R,X<\HA`$`)&/`_P)A(,`I_U?Q5V$@P"CG```<YU#+
M`J8!`!S&$-`H90``'*4PT@)C0,`"_V/S4P``0`-CP/\"=P``)[<!`!SWPLXH
MY`(`)&$@P"G_$_%7_Z?_5^0"`"3_!_%782#`*'<``"9H```<"&'?`@D`%0`'
M`14`)@``',8@PP)E```<I4#1`F-`P`+_I_%38\#^`GG`P"FY`0`<.2/-*"P#
M`";-__\582#!*7<`P2EXX,`I>J#`*7N`P"ECM!``;!@@)UH``!3_2_%7M___
M%4R#@`.,C1``]Z*_`Y?=$``F```4B``5`&D``!PI`=`"9P``'.<`T`+&!,`"
M!02``N0"%0#_?_)7V/__%4R#@`.,C1``&,._`YCA$`#D`A4`)@``%`4#%0#_
MB_!7EX!``.!J`&#D!H`"_XOO5YH`%0"`'`!`^P(5`.8"%0`%`Q4`6^\0`/^O
M\%=@`P`I;1@@)BP#`"9$`Q4`K#D`7$T``!1CM!``82#!*'<`P2AXX,`H><#`
M*'J@P"A[@,`H8T#!`B```$P``$`#&@`5`/_#_U/_(_)7``!``__K_E,``$`#
M8\#\`GQ@PBGM__\5O`$`')R3R"@N```4=P##*7C@PBEYP,(I>J#"*6$@PRE[
M@,(I?4#"*8P#`"9CM!``VO__%<Y!@@--T[T#SHT0`)@`%0"Y`!4`9```'(3P
MRP+%M1``;(@0)_^7]5>7`!4`!;R``@0#%0#_;_!7@%@`0`4#%0!D```<A(#+
M`O^#]U<$`Q4`;8@0)HP#`":LK0%<+0``%&.T$`!A(,,H=P##*'C@PBAYP,(H
M>J#"*'N`PBA\8,(H?4#"*&-`PP(@``!,``!``P0#%0#_+^Y7FX!``&4``!RE
M4,H")`,5`/_+[5>=`!4`GXS_0RT``!2L08(#6>._`XR-$`"9Y1``K$&"`XR-
M$`!:X[T#FND0`*P#`"A[!X`"@-$`0```0`/@%@!`I0,5`.0"%0#_/^]7@)@`
M0*0#%0#_P^U7A(!``*R3$`"-_3\H#+R``JPA`%P.O(`"``!``X3\OP*LDQ``
MC?T_*(`!`"FN\?];9!,0``S\OP.$`?]C)@``%`4$@`(*`Q4`:0``'"FQQP*H
M`Q4`9P``'.>@QP(D`Q4`_R_P5T8#%0`E`Q4`!``5`/]_[E>`&`!$;!@`).X!
M`!0-`0`4C+D4`(U-`%AE```<I8#&`@0`%0#_U^Q7G0`5`)^8_D.L`P`HGSW_
M1^`:`$!E```<I9##`N0"%0#_<^Y7G\S_0WT``!R]0\,"!`2``O]C_U,%!(`"
M)`,5`/\3[5>?K/]')0,5`&0``!R$T,0"_]?U5R0#%0#_Y^Y7_U/^4__/[U>.
M```HC0`5`,`I`$```$`#K07``LR]P`.N`0`HA#`3`*RQ$P"$,!4`W^G_1R``
M`$P@``!,``!``X`0`4!CP/\"=P``)V$@P"F,```HEP`5`(!1`$#_9^Q7AOS_
M`N::$`#F<@!LS0``*`R\@`*L30!<#;R``@`,`%#,```HC3T`7,;\_P+F]O]?
MS0``*`R\@`)D```<A(#"`JP1`%P``$`#9```'(3`_P)A(,`H=P``)F-`P`+_
M)^Y3#;R``@`,`%#,```HC1$`6,;\_P+F]O]KYKK_6PV\@`(`$`!0``!``\P`
M`"B-#0!<QOS_`N;V_VO&W!$`S`C``BT``!2L-0!HY0(5`"<``!3&!,`"I`$`
M'(2P_0+_Q^Y782#`*'<``":D`0`<A&#]`F-`P`(@``!,82#`*'<``"8$`!4`
M8T#``B```$P``$`#9```'(0@_0+_B^U3``!``V.`_@+L```<C+'U`G@@P2FX
M`0`<&`/Z*)`!`":/(<`HCD'`*(UAP"@1`P`FC(%`*F0``!R$X/X"86#!*7'@
MP"EP0,`I;V#`*6Z`P"EMH,`I;,!`*7=`P2G_8_-79```'(1P_@+_5_-79```
M'(1@_@+_2_-79```'(1P_@+_/_-79```'(1@_@+_,_-79```'(1P_@+_)_-7
M9```'(1@_`+_&_-79```'(10_@+_#_-79```'(1@_@+_`_-79```'(1P_@+_
M]_)79```'(3@^P+_Z_)7=S#``N4"%0!D```<A##^`O]W\5>`%`!`A0`5`&0`
M`!R$8/T"_W/S5^4"%0!D```<A`#^`O]3\5>`%`!`A0`5`&0``!R$$/X"_T_S
M5^4"%0!D```<A!#^`O\O\5>`2`!`A0`5`&0``!R$X/D"_ROS5V4``!RE</X"
M9```'(0P^P+_%_-7;>#`*`P#`":L;0!<86#!*'=`P2AX(,$H8X#!`B```$SE
M`A4`9```'(3P_`+_U_!7@!@`0(4`%0!D```<A*#Z`O_3\E?_J_]3!BB``F4`
M`!REL/P"9(3``O]SZ5>?D/]'9:S``F0``!R$\/D"_Z?R5_]__U/_I^Q78T#_
M`G>`P"FW`0`<]^+R*.P"`"9X8,`IN`$`'!BCZ@($`P`D;"#`*6&@P"D,_+\"
MC"@`6&T@P"CL`@`FK%D`7&&@P"AW@,`H>&#`*&/`P`(@``!,``!``V40P`)D
M```<A##X`O\G\%>`(`!`C```*`0`%0"`#0!`A,'``P20$@`$`P`E_[/_4P0`
M%0`$`P`E_Z?_4_\/[%=CP/\"82#`*?_CZ%?_G^M7@`@`0(0``"9A(,`H8T#`
M`B```$P``$`#8P#_`G?`P"FW`0`<]^+O*.P"`"9Y@,`I91#``ID`%0!D```<
MA.#X`F'@P"EXH,`I>F#`*6P@P"G_D^]7)0,5`(`0`$",```HF``5`(`]`$1D
M```<A"#X`O^#\5=M(,`H[`(`)JQ]`%QAX,`H=\#`*'B@P"AY@,`H>F#`*&,`
MP0(@``!,``!``_\+Z5>?T/]')`,5`/\_Z%>:`!4`!`,5`/\SZ%=$DQ``A`C`
M`O\WZ%<%!(`""@,5`&D``!PI(?("*`,5`&<``!SG,/("!OR_`IH`%0#_S^I7
M10,5`/]W_U/_`^M7``!``V.`^0(.`0`4#?__%7K@Q2E[P,4I86#&*7=`QBEX
M(,8I>0#&*7R@Q2E]@,4I?F#%*7]`Q2G/084#8[00`+H!`!Q:<^LH30,`)@S_
M_Q7OC1``A3'[`NRQ$`#/084#SB&%`\Z-$`#-`0`G;0``'*VA]`*-0?LI;0``
M'*TQ[0*-8?LI;0``'*V!\@*-`?PI;0``'*TQ]`*-(?PI;0``'*TA]`*-0?PI
M;0``'*T1]`*-8?PI;0``'*T!]`+OC1``C8'\*6T``!RM`?,"FP`5`(VA^RGE
ME1``;0``'*V1\P)D```<A'#M`H"!^RF`H?PIC<'[*8#A^RG_[^U7@!``0(P`
M`"B7`!4`@/T$1/_K_5>7`!4`@#`$0.0"%0#_T^97A`1!`(0$P`+_U^97[`(`
M*)D`%0"`.0!`.`,5`'P``!R<0_("Z`(`*@0#%0"'`Q4`!OR_`@4$@`+W!L`"
M_V/I5^P"`"@8"\`"G]W_1PT!`!3\_O\5K$&%`Y<#O`.,C1``E]T0`*Q!A0.<
M,[L#C(T0`&0``!R$4.X"G/$0```4`%```$`#]R+``N0"`":`8`%`A0,5`/\S
M[5>8`!4`G^C_0XP``"B?X?]#_T_S5Y_8_T,$`Q4`_SOH5YT`%0"`,`%```!`
M`Z0#%0#_!^97EP`5`"0#%0#_^^57[)(0`(R!0`",$9`"A`$5`)@!%0#_\^57
M*P,5`&H``!Q*`>\":0``'"DAZ0*H`Q4`9P``'.?0[@(&_+\"!02``IP`%0#_
M@^A7!0"'`H0#%0#_E^=7#/R_`HP4`%S_*^57B0``)`Q$@`(L=0-<'@$`%/G^
M_Q7,0X4#C(T0`";#O`.&F1``A0,5``0`%0#_^^=7EP`5`(#@`$"L`0`<C+'C
M*&<#`":$`0`FB`,5`&8``!S&(.X"!02``O_?YU<8`!4`#`$`%(PAA0.,C1``
MC0$`)DP#`"8$`Q4`K*4%7`T!`!1CM!``86#&*'=`QBAX(,8H>0#&*'K@Q2A[
MP,4H?*#%*'V`Q2A^8,4H?T#%*&.`Q@(@``!,#`$`%(Q!A0,<__\5C(T0`!@`
M%0"<\1``#',M`)=!^RC@.@!`[`(`*(`Q`$#D`A4`_]OQ5Q@'@`*?X/]#Y`(5
M`/_#YE>=`!4`GY#^1PQS+0"70?LH_]+_1QT`%0#_?_Y3S$.%`XR-$``=__\5
MG?40`*Q#_R3N`0`4C0``%(RY%`"-!?]?ODO_)/]+Y%>>^/Y?K$/_)`T`AP*,
M_4<#C>G^7P0#%0#_3^17#`$`%(Q!A0,E,[L#C(T0`)@`%0"%E1``9```'(3@
MZ@+_$^M7@$0"0'D#`";_+^97A0`5`"0#%0#_`_57G0`5`(`H`D"D`Q4`__/C
M5YF`0``,#(`")`,5`)DY`&2$\/\"90``'*7@Z0*DDQ``_S_E5X`@`$0,$(`"
M+(\#6"SSOP*LLQ``C?T_*`R\@`*L>0-8_QOZ5X`8`$0%`!4`I`,5`/];YE>;
M`!4`@,@!1&4``!RE,.0"9```'(1PX0+_A^Q7_]OD5XH`%0!K```<:P'L`DD`
M`!PI@=\"B`,5`&<``!SG<.@"!OR_`@4$@`($`Q4`_QOF5QG\OP(;1(`"?P``
M'/\SZP)>```<WK/>`GT``!R]\^<"`$0`4/^SXE>,```DFTD`7/]WY%?L!H`"
MB@`5`'\``">+`14`R0,5`(@#%0"G`Q4`!OR_`@4$@`($`Q4`EP$5`/^WY5<%
M`(<"!`,5`/_+Y%>9M/];A`,5`/]_Y%<%`Q4`1```'(10W`+_Q^M7!`,5`/_G
M^5?_?_U3``!``PT!`!3Y_O\5K$&%`XR-$``Y,[L#F>40`*Q!A0,<__\5C(T0
M`&0``!R$<.`"&``5`)SQ$`"`*`!`)0,5`/]GZ5<8!X`"@`P`0(P``"B`+0!$
M#',M`(2A^RB?X/]'!#2``O];XE>9`!4`5P``'/>"WP+_A_M3``!``_]3Y%>7
M`!4`GU3[1PQS+0"$H?LH_\__4XP!`!R,H=8H9P,`)H0!`":(`Q4`9@``',80
MX`(%!(`"_YOD5Q@`%0#_O_Q3``!``_\;^5?D`A4`_P/D5Y@`%0#_I_Q3``!`
M`WT#`";_V_U3!@B``@6XOP+_$^)7&0$`%/?^_Q4L0X4#C(T0`/?BOP.7W1``
M!AB``N4"%0!D`Q4`_WOB5RU#A0.MC1``#/__%:RQ$`"-X3\JH!$`1(WE/RH.
M#($"KGT!6`8`%0`%`!4`9`,5`/^WX5<`D!U4#`$`%/?^_Q6,084#^>*_`XR-
M$`"=`!4`F>40```4`%```$`#)0,5`*0#%0``T!U4!@$`%"4#%0!D`Q4`_P/B
M5X:`0``&X/]C9`,5`/\3XU<;`0`4;$.%`XR-$`#WPKX#F=T0`*4#%0`D`Q4`
M`%@B5&Q#A0/W8L`"C(T0`)?=$`#]HL`"6P``''OCV@(H`P`JY`(5`&<#%0`&
M_+\"!02``O<*P`+_B^-7.0?``K?C_U\.`0`4S4&%`ZV-$``,__\5BB'_`JRQ
M$`#-084#K8T0`&L``!QK<>`"JJD0`$D``!PIX=,"B`,5`$<``!SGD-P"!OR_
M`@4$@`($`Q4`@,$_*?\OXU>$`Q4`_P?B5P4#%0!$```<A'#2`O]/Z5<$`Q4`
M_V_W5_\'^U-Y(\`H/XO\0R0#%0#_*^!7#`R``H1Y_&^$\/\"10``'*4`VP(D
MDQ``_W_A5[T3$P`DDQ,`O1,5`/]7_%./Z3\J#@2!`NZ!_E^.[3\JS7G^7X[Q
M/RH-(($"S6W^7XWU/RH,%($"K&'^7P8(@`(%&+\"9`,5`/\3X%?E`A4`!J2`
M`F0#%0#_D^!72P``'&OQW`+J`A4`20``'"EAT`*(`Q4`1P``'.<0V0(&_+\"
M!02``@0#%0#_4^)7_Z_\4_^+XE<``$`#8P#^`F'@P2EWH,$I>(#!*7E@P2EV
MP,$I>D#!*7L@P2E\`,$I?>#`*7[`P"E_H,`IEP$`'/<"RBB,`0`<C*')*(P!
M`";D`@`D>5#``FQ@P"EY(,`I_\_?5Y@`%0#D`@`D_\/?5PSC`BHE`Q4`C.0"
M*40``!R$X,X"__/E5X`0`$"-```H#,2``JSI`EC_A_-7Y`(`)/^/WU<'+(`"
M!@2``D4``!REX-8"_TO?5X"\`D"Z`0`<6D/*`HQ`P"A-`P`D#@2``INAP"CV
M`@`DS<4`9!Q``!08`!4`&02``KX!`!S><\D"G`.0`AT`D`(`*`!0!4+`*.0#
M%0#_Z]]73@,`)("(`$0M!X`"&`>``KD!%0"N>0!DQ`(5`/\+WU<'`!4`!@,5
M`&4#%0#_&^!7@%0"0)```";.`P`F]@(`)`T.`"0N.RT`WP$`)JWQ%`"]I?];
M9```)\0"%0#_R]Y7;P``)@<(@`(&`!4`Y0$`)O\WX5>%`!4`Y`,5`/]KWU?V
M`@`D3@,`))^`_T/-_;\"N'T!6,0"%0#_C]Y7!PR``@8$@`)%```<I0#3`O]+
MWE>8`!4`@#0`0.0"`"3_:]Y7#$/`*$8``!S&H-("A0$`)O\WWE<,0\`HC`$`
M)HP-`"2,V78`@-T!1.0"`"3_.]Y7!PR``@8$@`)%```<I?#1`O_WW5>8`!4`
M@#0`0&4@P"A$```<A!#'`O]7Y%>9`!4`Y`(`)"![`4#__]U7#$/`*"8#%0"%
M`0`F_\_=5^0"`"2X`0`<&#/$`O_?W5>9`!4`Y`(`)/_3W5<&!(`"10``'*6`
MT`+_X]Q7A0`5`$8``!S&H-`")`,5`/^/W5?D`@`D_Z?=5V4@P"B`Y`(I1```
M'(3@Q`+_V^-7!`,`)Y<`%0"`I`!`!0"'`N0"%0#_N]Y7#$2``HP0`%B,!(`"
M#02``JP=`6B,`0`<C('_*&U@P"B,`0`FK`4!7&'@P2AVP,$H=Z#!*'B`P2AY
M8,$H>D#!*'L@P2A\`,$H?>#`*'[`P"A_H,`H8P#"`B```$P-!(`"KH7^9Q@$
M@`(``$`#Q`(5`/\'W5=E`Q4`_[_<5TT#`"0,!X`"F`$5`/8"`"2-X?]C_U?^
M4ZP!`!R,X?\"A`$`)O\_]%<$`P`GEP`5`)](_T=$```<A/#,`O]?WE?V`@`D
M_R?^4XP$`"B?'?U#_Q?]4P``0`-.`P`D]@(`),W]OP*X!?Y?_WO_4P``0`/_
MB]Q7K`$`'(QQ_@*-`0`F#$/`**4!`":$`0`F_W?I5_^#_E/D`@`D_V/<5PQ#
MP"B%`0`F_^?=5_\7_E/_K]Y7K`$`'(R!_0*,`0`FAP`5`.8"%0"%`0`F1```
M'(1`RP+_R]U7``!``V.`_P)W0,`I>"#`*6%@P"F8`!4`_]_N5XT``"B7`!4`
MH"4`0```0`.$!,`"K+W``XT``"CW,A,`C+`3`/<R%0"_Z?]'_Y_Q5X`H`$``
M)P!`#`,`*(`=`$`&$(`"10``'*7PPP+D`A4`_\O:5X`8`$!A8,`H=T#`*'@@
MP"AC@,`"(```3&%@P"AW0,`H!`,5`'@@P"AC@,`"_VOF4P``0`.2`0`<4@+X
M*$P"`"9C0/4";2#``N4!`!1AH,HI=X#**7A@RBEY0,HI;"#**9'@P`*'X,$"
MLP$5`*4`O`,&_@$4,`(`)BX"`"0Q(L`"#X)%``RB10#T84$`$.)%`(R5%`",
M014`SC$``)`"WP#O(4$`SL%,`(Q!%0#OF10`S@'?`(P]%0!N`@`G;"+`*7-"
MP`+QL/]?L0'(`JRAP2BP`<$HKT'`**X!`":,P14`C+T5`(RY%0".!4$`C'U%
M`,PQ%0",`=\`K`'"*:TAP`*QS?]?E```)I!`P"B18,`H9B#`*(\@P"B3@,`H
MY02U%*5DI@.-;D4`C!9!`(PU%0#&E!``#<85`.=Y00#&S!``K;T4`.X)10",
M`=\`[C@5`*W%%0",F1``:$#`*,8!WP",M1``C`'?``V:%0");44`")40`(<5
M00"MT10`",40`*W!%0#G)!4`K:$0`.<`WP")>D$`K9T0`(@*10!G8,`H*"$5
M`*T!WP#.H14`JFU%`,ZQ%`#GE!``J15!`.?`$`#.F14`*2D5`,Z=$``I`=\`
MAWE!`&J`P"B,"44`YS`5`,RE$`",`=\`#IT5`(D500"+;44`"`'?`,ZU%`!*
ME1``2ID0`,ZA%0`F+14`SJD0`,8`WP"I>4$`:J#`**T)10`I-14`S9D0`*8!
MWP#MI!4`2I40`,ML10#G`-\`K;$4`,X400!(H1``K9T5`,XM%0"MH1``S@'?
M`(AY00","44`"#$5`*RY$`!MP,`HC@'?`"RA%0"ME1``*0'?`,MM10",F10`
MRA5!`*>=$`",I14`2BT5`(R=$`!*`=\`S0A%`(RI$`#'>$$`:N#`*.<T%0"-
M`=\`#)T5`*8500"K;44`"`'?`(RY%`!*E1``2J40`(RA%0#)+!4`C*D0`"D!
MWP#&>4$`:@#!*,X)10#&.!4`C*40`(X!WP#LF!4`2I40`,MM10#G`-\`C+44
M`,D500!(H1``C)T5`"DM%0",H1``*0'?`*AY00!J(,$HK0E%``@U%0",I1``
MC0'?`,R@%0!*E1``JVU%`,8`WP",N10`J15!`$>=$`",F14`*2T5`(R=$``I
M`=\`QWE!`&I`P2C."44`YS@5`(RE$`".`=\`#)T5`$J5$`#+;44`"`'?`(RU
M%`#)%4$`1ID0`(RA%0`I+14`C)D0`"D!WP"F>4$`:F#!**T)10#&-!4`C*40
M`(T!WP#LF!4`2I40`*MM10#G`-\`C+D4`*D500!(H1``C)T5`"DM%0",H1``
M*0'?`,AY00!J@,$HS@E%``@Y%0",I1``C@'?`,R@%0!*E1``RVU%`,8`WP",
MM10`R15!`$>=$`",F14`*2T5`(R=$``I`=\`IWE!`&J@P2BM"44`YS05`(RE
M$`"-`=\`#)T5`$J5$`"K;44`"`'?`(RY%`"I%4$`1ID0`(RA%0`I+14`C)D0
M`"D!WP#&>4$`:L#!*,X)10#&.!4`C*40`(X!WP#LF!4`2I40`,MM10#G`-\`
MC+44`,D500!(H1``C)T5`"DM%0",H1``*0'?`*AY00!JX,$HK0E%``@U%0",
MI1``C0'?`,R@%0!*E1``JVU%`,8`WP",N10`J15!`$>=$`",F14`*2T5`(R=
M$``I`=\`QWE!`&H`PBC."44`YS@5`(RE$`".`=\`#)T5`$J5$``(`=\`RVU%
M`(RU%`#)%4$`1ID0`(RA%0`I+14`C)D0`"D!WP"F>4$`:B#"**T)10#&-!4`
MC*40`(T!WP#LF!4`J15!`.<`WP"K;44`C+D4`$J5$`!*H1``C)T5`"@M%0",
MJ1``"`'?`,EY00!J0,(HS@E%`"DY%0",H1``C@'?`,RD%0#(%4$`Q@#?`,MM
M10",M10`2I40`$J=$`",F14`!RT5`(RI$`#G`-\`J'E!`&I@PBBM"44`"#45
M`(R=$`",`=\`+:$5`(<500"+;44`*0'?`*VY%`!*E1``2ID0`*VE%0#F+!4`
MQWE!`,X)10#G.!4`K:D0`&Z`PBC&`-\`IID0`,H`WP`-G14`Q940`$MM10`(
M`=\`K;$4`$X500"II!``K:$5`,XM%0"MI1``S@'?`(EY00!KH,(HC`E%`*VY
M$``I,14`SK/=%,Z%K@.E`=\`[*05`&NY$`"W;$4`C)D5`*8400!HH1``QEP5
M`(P!WP",H1``Q@#?`(:9$`!(>4$`;,#"*$H)10`(*14`*Z$5`,H`WP#W`-\`
MC+D0`&>U%0!+;44`315!`(S=$`#G`-\`K2T5`(R=$`"M`=\`IWA!`*4(10#G
M%!4`A;40`&S@PBBK`-\`#9T5`'=M10",N1``*0'?`*:9%0!M%4$`C*40`,8`
MWP"M714`C)D0`*T!WP"-M1``1GE!`&P`PRA*"44`QB@5`.F8%0"J`=\`%P'?
M`(RY$``HE14`26U%`$4500",W1``"`'?`*4D%0",H1``I0#?`(65$`!H>4$`
M;"##*&L)10`(+14`J0#?`,N@%0#W`-\`C+D0`&>U%0`K;44`+15!`(S=$`#G
M`-\`K2T5`(R=$`"M`=\`C;40`$=Y00!L0,,H2@E%`.<H%0`+G14`J@'?`-<`
MWP",N1``9I45`$MM10!%%4$`C-T0`,8`WP"E+!4`C)D0`*4`WP"%E1``)GE!
M`&Q@PR@I"44`QB05`.N8%0"I`-\`%P'?`(RY$`!HM14`*VU%`"T500",W1``
M"`'?`*TM%0",H1``K0'?`(VU$`!(>4$`;(##*$H)10`(*14`RZ`5`*H!WP#W
M`-\`C+D0`&>5%0!+;44`115!`(S=$`#G`-\`I2P5`(R=$`"E`-\`A940`"=Y
M00!LH,,H*0E%`.<D%0`+G14`J0#?`-<`WP",N1``9K45`"MM10`M%4$`C-T0
M`,8`WP"M+14`C)D0`*T!WP"-M1``1GE!`&S`PRA*"44`QB@5`.N8%0"J`=\`
M%P'?`(RY$`!HE14`2VU%`$4500",W1``"`'?`*4L%0",H1``I0#?`(65$``H
M>4$`;.##*"D)10`()14`RZ`5`*D`WP#W`-\`C+D0`&>U%0`K;44`+15!`(S=
M$`#G`-\`K2T5`(R=$`"M`=\`C;40`$=Y00!L`,0H2@E%`.<H%0`+G14`J@'?
M`-<`WP",N1``9I45`$MM10!%%4$`C-T0`,8`WP"E+!4`C)D0`*4`WP"%E1``
M)GE!`&P@Q"@I"44`QB05`.N8%0"I`-\`%P'?`(RY$`!HM14`*VU%`"T500",
MW1``"`'?`*TM%0",H1``K0'?`(VU$`!(>4$`;$#$*$H)10`(*14`RZ`5`*H!
MWP#W`-\`C+D0`&>5%0!+;44`115!`(S=$`#G`-\`I2P5`(R=$`"E`-\`A940
M`"=Y00!L8,0H*0E%`.<D%0`+G14`J0#?`-<`WP",N1``9K45`"MM10`M%4$`
MC-T0`,8`WP"M+14`C)D0`*T!WP"-M1``1GE!`&R`Q"A*"44`QB@5`*L!WP#J
MF!4`%P'?`(RY$`!(E14`:FU%`&4500",W1``"`'?`*4H%0",H1``I0#?`(65
M$``H>4$`;*#$*"D)10`()14`J@#?`,F@%0#W`-\`C+D0`">U%0!);44`315!
M`(S=$`#G`-\`K245`(R=$`"M`=\`C;40`&EY00!LP,0H:PE%`"DM%0`'I14`
MJP'?`-<`WP",N1``Y905`&8500!G;44`C-T0`*4`WP#&'!4`C)40`,8`WP"&
MF1``1WE!`&S@Q"A*"44`YR@5`"6=%0#*`-\`5VU%`(RY$``(`=\`K;05`$45
M00",H1``K0'?`*5<%0",M1``I0#?`(R5$`!M>4$`90#%*&L)10"M+14`B`'?
M`.RT%0"EN!``*0'?`(Z9%0`&;44`#!5!`*6D$`#.`=\`C!D5`*6X$`",`=\`
M3GE!`*6P$`!*"44`9B#%*&PW'A7.*14`C'&S`PP``!;)`=\`J@'?`*TY%0"E
M`-\`6*44`.L`WP"MH10`QK`0`+=L10#&K!``IQ1!`*UA%0`+>4$`YUP5`*V9
M$``&"44`9AD5`.<`WP!K0,4HK9T0`*T!WP#(`-\`SAD5`#BA%`!KL1``MVU%
M`,Z5%`"G%4$`:JD0`,YA%0#G7!4`SJD0`.<`WP"J>$$`:V#%**4(10!%%14`
MSIT0`,<!WP"J`-\`QA05`!BI%`#N%$$`]VQ%`,:T%`!KL1``:Z40`,9@%0#)
M714`QJP0`"D!WP"N>4$`:X#%**T)10#.-14`S:00`*8!WP#)`=\`I3@5`%BE
M%`#-%$$`UVQ%`*6<%`!KL1``:Z$0`*5@%0"H714`I:P0``@!WP#M>$$`:Z#%
M*.<(10"M'14`I:`0`*<`WP"H`=\`SC45`#BA%`#E%$$`]VQ%`,Z9%`!KL1``
M:ZD0`,YA%0"J7!4`SJT0`$H!WP#%>$$`:\#%*,8(10"E&!4`SJD0`,8!WP"J
M`-\`K145`!BI%`#.%$$`UVQ%`*V=%`!KL1``:Z40`*UA%0#)714`K:T0`"D!
MWP#N>$$`:^#%*.<(10#.'14`K:40`*<!WP#)`=\`I3@5`%BE%`#M%$$`]VQ%
M`*68%`!KL1``:Z$0`*5@%0"H714`I:P0``@!WP"EH!``S7A!`,8(10"M&14`
MI@#?`&4`QBBK`=\`SC45`#BM%`"EL!``UVQ%`,Z=%`#(%$$`JJ@0`,YA%0`(
M714`SJD0``@!WP#E>$$`:B#&*.<(10"E'!4`SJ$0`,<!WP"H`-\`K145`'BA
M%`#N%$$`]VQ%`*V9%`!*L1``2J40`*UA%0#)714`K:D0`"D!WP"MI1``SGA!
M`,8(10#.&14`I@'?`&U`QBC*`=\`I3@5`!BI%`"ML1``UVQ%`*6<%`#)%$$`
MJZT0`*5@%0`I714`I:P0`"D!WP#M>$$`:V#&*.<(10"M'14`I:00`*<`WP"I
M`=\`SC45`%BE%`#E%$$`]VQ%`,Z9%`!KL1``:Z$0`,YA%0"H7!4`SJT0``@!
MWP#.H1``Q7A!`,8(10"E&!4`Q@'?`&Z`QBBK`-\`K145`#BM%`#.L1``UVQ%
M`*V=%`#(%$$`RJD0`*UA%0`(714`K:D0``@!WP#N>$$`:J#&*.<(10#.'14`
MK:$0`*<!WP#(`=\`I3@5`'BA%`#M%$$`]VQ%`*68%`!*L1``2J40`*5@%0"I
M714`I:@0`"D!WP"EI!``S7A!`,8(10"M&14`I@#?`&7`QBBJ`=\`SC45`!BI
M%`"EL!``UVQ%`,Z=%`#)%$$`JZP0`,YA%0`I714`SJT0`"D!WP#E>$$`:^#&
M*.<(10"E'!4`SJ40`,<!WP"I`-\`K145`%BE%`#N%$$`]VQ%`*V9%`!KL1``
M:Z$0`*UA%0#(714`K:T0``@!WP"MH1``SGA!`,8(10#.&14`I@'?`&T`QRC+
M`=\`I3@5`#BM%`"ML1``UVQ%`*6<%`#(%$$`JJD0`*5@%0`(714`I:@0``@!
MWP#M>$$`:B#'*.<(10"M'14`I:`0`*<`WP"H`=\`SC45`'BA%`#E%$$`]VQ%
M`,Z9%`!*L1``2J40`,YA%0"I7!4`SJD0`"D!WP#.I1``Q7A!`,8(10"E&!4`
MQ@'?`&Y`QRBI`-\`K145`!BE%`#.L1``UVQ%`*V=%`#*%$$`RZT0`*UA%0!*
M714`K:T0`$H!WP#N>$$`:V#'*.<(10#.'14`K:D0`*T!WP#'`=\`I3@5`#B=
M%`"J%4$`MVU%`*68%`!KL1``:Z$0`*5@%0!(714`I:P0`'>`QR@(`=\`RGA!
M`,8(10!*&14`I:`0`*L`WP!(`=\`SBD5`,ZU%`#YH!0`][(0`'AM10!F%4$`
MZ:80`,QE%0#&8!4`C*40`*X)10"I>4$`Q@#?`"DY%0"&F1``V`#?`$VE%0",
MQ905;J#'*`IO10"ME14`C%G'`@4700`,```6I2@5`&IY00!K"44`2BT5`,ZQ
M$`#'G1``K0'?`"ZI%0"MG1``SID5`*4`WP!FP,<HI940`+<`WP#&L!``YVY%
M`.T600#(H!``K1T5`,X!WP#.H1``K0'?`,ZU$``(>T$`;>#'*!@+10`(814`
MRP'?`$:A%0!G;44`K;$0`"D!WP#%E!4`9A5!`*VE$`"E`-\`QAP5`*V5$`#&
M`-\`IID0`.=Z00!M`,@H]PI%`.=<%0`%G14`UP#?`.EN10"ML1``2@'?`*ZX
M%0#E%D$`K:D0`,X!WP"E)!4`K;D0`*4`WP"EE1``:7E!`&T@R"AK"44`*2T5
M`.ZD%0"K`-\`:FU%`*VQ$``(`=\`QID5`&X500"MH1``Q@#?`,XI%0"MF1``
MS@'?`*ZY$`#H>D$`;4#(*/<*10`(714`R@'?`":A%0!7;44`K;$0`.<`WP#&
ME!4`115!`*V=$`#&`-\`I5P5`*V9$`"E`-\`I940`&=Y00!M8,@H:PE%`.<L
M%0`&G14`JP#?`'=M10"ML1``*0'?`,:X%0!N%4$`K:40`,8`WP#.714`K9D0
M`,X!WP"NN1``1GE!`&V`R"A*"44`QB@5`.F8%0#*`=\`%P'?`*VQ$``HE14`
M26U%`$4500"MW1``"`'?`*4D%0"MH1``I0#?`*65$`!H>4$`;:#(*&L)10`(
M+14`J0#?`,N@%0#W`-\`K;$0`&>Y%0`K;44`+A5!`*W=$`#G`-\`SBT5`*V=
M$`#.`=\`KKD0`$=Y00!MP,@H2@E%`.<H%0`+G14`R@'?`-<`WP"ML1``9I45
M`$MM10!%%4$`K=T0`,8`WP"E+!4`K9D0`*4`WP"EE1``)GE!`&W@R"@I"44`
MQB05`.N8%0"I`-\`%P'?`*VQ$`!HN14`*VU%`"X500"MW1``"`'?`,XM%0"M
MH1``S@'?`*ZY$`!(>4$`;0#)*$H)10`(*14`RZ`5`,H!WP#W`-\`K;$0`&>5
M%0!+;44`115!`*W=$`#G`-\`I2P5`*V=$`"E`-\`I940`"=Y00!M(,DH*0E%
M`.<D%0`+G14`J0#?`-<`WP"ML1``9KD5`"MM10`N%4$`K=T0`,8`WP#.+14`
MK9D0`,X!WP"NN1``1GE!`&U`R2A*"44`QB@5`.N8%0#*`=\`%P'?`*VQ$`!H
ME14`2VU%`$4500"MW1``"`'?`*4L%0"MH1``I0#?`*65$``H>4$`;6#)*"D)
M10`()14`RZ`5`*D`WP#W`-\`K;$0`&>Y%0`K;44`+A5!`*W=$`#G`-\`SBT5
M`*V=$`#.`=\`KKD0`$=Y00!M@,DH2@E%`.<H%0`+G14`R@'?`-<`WP"ML1``
M9I45`$MM10!%%4$`K=T0`,8`WP"E+!4`K9D0`*4`WP"EE1``)GE!`&V@R2@I
M"44`QB05`.N8%0"I`-\`%P'?`*VQ$`!HN14`*VU%`"X500"MW1``"`'?`,XM
M%0"MH1``S@'?`*ZY$`!(>4$`;<#)*$H)10`(*14`RZ`5`,H!WP#W`-\`K;$0
M`&65%0!'%4$`2VU%`*W=$`"E`-\`YRP5`*V5$`#G`-\`IYT0`"5Y00!MX,DH
M*0E%`*4D%0`+E14`Z0#?`*VQ$`#7`-\`;KD5`"8500`K;44`S@'?`*W=$`#&
M+!4`K;D0`,8`WP"MF1``I@'?`$YY00!M`,HH2@E%`,XI%0"JN!4`K+$0`$>=
M%0`(`=\`S11!`,IL10",H1``YP#?`*TI%0"M`=\`C)T0`(RU$`",`=\`+7E!
M`(S1$``I"44`C`'?`*TE%0",```GK0'?`,X!WP"L`-\`K<$0`,[%$`#OF1``
MC,T0`'$@RBA0`@`F[P'?`*T!WP#.`=\`C`'?`(\@P"F-0,`ICF#`*8R`P"DP
M'@!<8:#**'>`RBAX8,HH>4#**&/`R@(@``!,_^?&5V/`_P($`(("82#`*?_7
MPU>N=3$5SOFS`PX``!9/F]\5S:6'%8Y`P"GO):X#K<''`E"*SA2N9"`4#P``
M%@T``!80!LP"SMG1`I```">/(,`ICF#`*8V`P"F`H,`I@,#`*8#@@2EA(,`H
M8T#``B```$QC@/T"=R#"*7K`P2E[H,$I?(#!*6%@PBEV0,(I>`#"*7G@P2E]
M8,$I?D#!*7\@P2F-H,`HCL#`*)H`%0#,-"T`C`'?`(VU$@#.M1``A'@`),UT
M10"MN1``3*/`*4W#P"G7`!4`O``5`%OCP`*`A`!`&0"!`BP3$0"8&1(`C&$3
M`-C@$P"8814`!@,5`&23$`#_(\173'L`)`T#%0",81``3..!*9D]`%AA8,(H
M=D#"*'<@PBAX`,(H>>#!*'K`P2A[H,$H?(#!*'U@P2A^0,$H?R#!*&.`P@(@
M``!,``!``T0#%0#W8A$`G+<0`/^GYU<,_(`"E\T#9.P"OP)L\(`IC)E$`&S@
M@"F,`=\`C`7``HP900",LQ``;*#`*7K`P"F(,P`JC#L`*HT_`"J.0P`JCT<`
M*I!+`"J13P`JDE,`*I-7`"J46P`J@2,`*HLG`"J**P`JB2\`*H<W`"J6!P`J
MGPL`*IX/`"J=$P`JFA<`*ID;`"J8'P`J:`@`*6P,`"EM$``I;A0`*6\8`"EP
M'``I<2``*7(D`"ES*``I="P`*81?`"J%8P`JAF<`*HQO`"J-<P`JCG<`*H][
M`"J0?P`JD8,`*I*'`"J3BP`JE(\`*I=K`"ID,``I930`*823`"J%EP`J9C@`
M*8:;`"IL0``I;40`*6Y(`"EO3``I<%``*7%4`"ER6``I<UP`*71@`"ED9``I
M96@`*69L`"EW/``IEY\`*HRC`"J-IP`JCJL`*H^O`"J1MP`JDKL`*I._`"J4
MPP`JA,<`*H7+`"J0LP`JAM,`*G=P`"EL=``IE\\`*FUX`"EN?``I;X``*7&(
M`"ERC``ID>L`*I+G`"ISD``I=)0`*9/C`"J4WP`J9)@`*66<`"F$VP`JA=<`
M*G"$`"F0[P`JC/\`*H_S`"J.]P`JC?L`*H@#`"IG-P`I9PP`*F@#`"EH"``J
M9SL`*6<0`"IA(P`I:R<`*6<_`"EG%``J:BL`*6DO`"EG0P`I9Q@`*F@S`"EV
M!P`I9T<`*6<<`"I_"P`I?@\`*6=+`"EG(``J?1,`*7H7`"EY&P`I>!\`*6=/
M`"EG)``JG`/!`F=3`"EG*``J9U<`*6<L`"IG6P`I9S``*F=?`"EG-``J9V,`
M*6<X`"IG9P`I9SP`*F=K`"EG0``J9V\`*6=$`"IG<P`I9T@`*F=W`"EG3``J
M9WL`*6=0`"IG?P`I9U0`*F>#`"EG6``J9X<`*6=<`"IGBP`I9V``*F>/`"EG
M9``J9M,`*7?/`"EGDP`I9V@`*F>7`"EG;``J9YL`*6=P`"IGGP`I9W0`*F>C
M`"EG>``J9Z<`*6=\`"IGJP`I9X``*F>O`"EGA``J9[,`*6>(`"IGMP`I9XP`
M*F>[`"EGD``J9[\`*6>4`"IGPP`I9Y@`*F?'`"EGG``J9\L`*677`"EDVP`I
M9,#`*&S_`"ETWP`I<^,`*7+G`"EQZP`I<.\`*6_S`"EN]P`I;?L`*?\[Y%=L
MH,`HC,/\7VPX`"1ZP,`HEYE``&P\`"2771$`9:#`*.8"%0!D`Q4`_R_`5U?C
M@2EA8,(H=D#"*'<@PBAX`,(H>>#!*'K`P2A[H,$H?(#!*'U@P2A^0,$H?R#!
M*&.`P@(@``!,?*#`*?^W_U-C0/\"=X#`*7A@P"EY0,`I>P``)V&@P"EZ(,`I
MK"@`)+HP`"2[X,`"F0$5`(R-:`".`14`#P"^`HP%@`(Y,P``6C,``(T!%0!O
M.Q`X!N"``I@`%0"W`!4`.<-,`%K#3`!DMQ``S#P!9`8`@0+&,!$`!0`5`/^7
MP%?D`A4`_T_C5P;@@`(%`!4`9`,5`/]_P%?ZPH$I^=*!*>0"%0#_+^-7[`(`
M)N0"%0",844`#`,`*>P"`":,044`#`<`*>P"`":,(44`#`L`*>P"`"8,#P`I
M["+`*(QA10`,$P`I["+`*(Q!10`,%P`I["+`*(PA10`,&P`I["+`*`P?`"GL
M0L`HC&%%``PC`"GL0L`HC$%%``PG`"GL0L`HC"%%``PK`"GL0L`H#"\`*>QB
MP"B,844`##,`*>QBP"B,044`##<`*>QBP"B,(44`##L`*>QBP"@,/P`I[(+`
M*(QA10`,0P`I[(+`*(Q!10`,1P`I[(+`*(PA10`,2P`I[(+`*`Q/`"EAH,`H
M=X#`*'A@P"AY0,`H>B#`*'L``"9CP,`"_Z^^4\8P$0`%`!4`_V._5__G_E-C
M`/\"=\#`*7F`P"E7`0`<][+N`ED!`!PYL^X".=\1`&'@P"EXH,`I>F#`*7M`
MP"E\(,`I.0])`"`[`$#<`!4`NP`5`)H`%0`8`!4```!``^P"`":&`Q4`90,5
M`$0#%0`8!\`"@0$`3/<BP`(XY_]?8>#`*'?`P"AXH,`H>8#`*'I@P"A[0,`H
M?"#`*&,`P0(@``!,``!``R```$P``$`#3`$`'(SA_P*'`0`F#```'H`MO4\`
M`$`#`0`"```````N`````````"XN````````)7,O)7,````O<')O8R]S96QF
M+V5X90``1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R``````!);G1E<FYA
M;',Z.E!!4CHZ0D]/5`````!E>&4``````"]P<F]C+R5I+R5S``````!005)?
M5$5-4```````````4$%27U!23T=.04U%`````#H`````````+P`````````E
M<R5S)7,``%!%4DPU3$E"``````````!015),3$E"`%!%4DPU3U!4````````
M``!015),24\``%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1```````4$%2
M7T-,14%.`````````%!!4E]$14)51P````````!005)?0T%#2$4`````````
M4$%27T=,3T)!3%]$14)51P``````````4$%27T=,3T)!3%]435!$25(`````
M````4$%27U1-4$1)4@```````%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,
M7T-,14%.``````````!005)?0TQ%04X]````````,0````````!,1%],24)2
M05)97U!!5$@`55-%4@````!365-414T``"]T;7``````5$U01$E2``!414U0
M1$E2`%1%35``````5$U0``````!54T523D%-10``````````)3`R>`````!P
M87(M`````"5S)7,E<R5S```````````E<SH@8W)E871I;VX@;V8@<')I=F%T
M92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*````````)7,Z
M('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E
M;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@```````%!!5$@`
M````<&%R;``````N<&%R`````"5S)7-C86-H92TE<R5S```E<R5S=&5M<"TE
M=25S````)7,E<W1E;7`M)74M)74E<P``````````05)'5@`````8````````
M`'!E<FP`````,`````````!005(Z.E!A8VME<CHZ5D524TE/3@`````Q+C`T
M.0```%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y```````````E
M<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@
M9F%I;&5D("AE<G)N;STE:2D*```````````M90```````"TM````````979A
M;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[
M(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP86-K86=E(%]?<&%R
M7W!L.PIM>2`H)%!!4E]-04=)0RP@)'!A<E]T96UP+"`D<')O9VYA;64L($!T
M;7!F:6QE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E
M($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@
M1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N
M86UE*"1P87)?=&5M<"D["F]U=',H<7%[4F5M;W9I;F<@9FEL97,@:6X@(B1P
M87)?=&5M<")]*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@
M*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?
M=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2![
M"FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A8
M6%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I
M+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*<')I;G0@)'1M
M<"`B(R$O8FEN+W-H"G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M
M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H
M96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@
M)R(@+B`D=&UP+3YF:6QE;F%M92`N("(G"B(["F-H;6]D(#`W,#`L)'1M<"T^
M9FEL96YA;64["FUY("1C;60@/2`D=&UP+3YF:6QE;F%M92`N("<@/B]D978O
M;G5L;"`R/B8Q("8G.PIC;&]S92`D=&UP.PIS>7-T96TH)&-M9"D["F]U=',H
M<7$H4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A
M;G5P.B`I"BX@)'1M<"T^9FEL96YA;64I.PI]"GT@?0I"14=)3B!["DEN=&5R
M;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z
M.D)/3U0["B1005)?34%'24,@/2`B7&Y005(N<&U<;B(["F5V86P@>PI?<&%R
M7VEN:71?96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY
M("5#;VYF:6<@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@
M/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7
M:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]
M/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T
M7W!R;V=N86UE*"D["E]S971?<&%R7W1E;7`H*3L*;7D@*"1S=&%R=%]P;W,L
M("1D871A7W!O<RD["GL*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT[
M"F]P96X@7T9(+"`G/"<L("1P<F]G;F%M92!O<B!L87-T.PIB:6YM;V1E*%]&
M2"D["FUY("1B=68["FUY("1S:7IE(#T@+7,@)'!R;V=N86UE.PIM>2`D8VAU
M;FM?<VEZ92`](#8T("H@,3`R-#L*;7D@)&UA9VEC7W!O<SL*:68@*"1S:7IE
M(#P]("1C:'5N:U]S:7IE*2!["B1M86=I8U]P;W,@/2`P.PI](&5L<VEF("@H
M;7D@)&T@/2`D<VEZ92`E("1C:'5N:U]S:7IE*2`^(#`I('L*)&UA9VEC7W!O
M<R`]("1S:7IE("T@)&T["GT@96QS92!["B1M86=I8U]P;W,@/2`D<VEZ92`M
M("1C:'5N:U]S:7IE.PI]"G=H:6QE("@D;6%G:6-?<&]S(#X](#`I('L*<V5E
M:RA?1D@L("1M86=I8U]P;W,L(#`I.PIR96%D*%]&2"P@)&)U9BP@)&-H=6YK
M7W-I>F4@*R!L96YG=&@H)%!!4E]-04=)0RDI.PII9B`H*&UY("1I(#T@<FEN
M9&5X*"1B=68L("1005)?34%'24,I*2`^/2`P*2!["B1M86=I8U]P;W,@*ST@
M)&D["FQA<W0["GT*)&UA9VEC7W!O<R`M/2`D8VAU;FM?<VEZ93L*?0IL87-T
M(&EF("1M86=I8U]P;W,@/"`P.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M(#0L
M(#`["G)E860@7T9(+"`D8G5F+"`T.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M
M(#0@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,#L*)&1A=&%?<&]S(#T@=&5L;"!?
M1D@["FUY("5R97%U:7)E7VQI<W0["G)E860@7T9(+"`D8G5F+"`T.R`@("`@
M("`@("`@("`@("`@("`@("`@("`@(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B
M"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*
M<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA
M;64@/2`D8G5F.PIO=71S*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B
M+BXN*2D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX
M?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@
M*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B
M=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@
M*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI
M)"]I*2!["FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B)&-R8R1E>'0B+"`D
M8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65]
M(#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M
M97T@/2`D9G5L;&YA;64["GT*96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S
M:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%27U1%35!]("D@>PIM>2`D9FEL
M96YA;64@/2!?=&5M<&9I;&4H(B1B87-E;F%M921E>'0B+"`D8G5F+"`P-S4U
M*3L*;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN(BD["GT*96QS92!["B1R97%U
M:7)E7VQI<W1[)&9U;&QN86UE?2`]"B1005(Z.DAE879Y.CI-;V1U;&5#86-H
M97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA
M;64@/3X@)&9U;&QN86UE+`I].PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO
M8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR
M971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1I;F9O(#T@
M9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T@;W(@<F5T=7)N.PHD24Y#
M>R1M;V1U;&5](#T@(B]L;V%D97(O)&EN9F\O)&UO9'5L92(["FEF("@D14Y6
M>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY
M("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@)"$["F)I;FUO
M9&4H)&9H*3L*<')I;G0@)&9H("1I;F9O+3Y[8G5F?3L*<V5E:R@D9F@L(#`L
M(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?=&5M
M<&9I;&4H(B1I;F9O+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D["F]P96X@
M;7D@)&9H+"`G/"<L("1F:6QE;F%M92!O<B!D:64@(F-A;B=T(')E860@)&9I
M;&5N86UE.B`D(2(["F)I;FUO9&4H)&9H*3L*<F5T=7)N("1F:#L*?0ID:64@
M(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86YN;W0@9FEN9"`D;6]D=6QE(5QN
M(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(
M96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ
M2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER
M92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@
M)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@
M;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@
M+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@
M)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<
M+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]
M"FQA<W0@=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B.PHD<W1A<G1?<&]S
M(#T@*'1E;&P@7T9(*2`M(#0[("`@("`@("`@("`@("`@(",@<W1A<G0@;V8@
M>FEP"GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H
M+"`D8V%C:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C
M('-A;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0HD
M<75I970@/2`P('5N;&5S<R`D14Y6>U!!4E]$14)51WT["FEF("@A)'-T87)T
M7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T
M*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I
M;G-T86QL7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@
M('9E<FEF>5]P87(**3L*:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR
M975S92<I('L*<VAI9G0@0$%21U8["B1%3E9[4$%27T%04%]2155317T@/2!S
M:&EF="!`05)'5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*
M;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O
M7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@
M)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G
M32<I('L*979A;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N
M<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O
M=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET
M92<["GT*96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*
M96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E
M<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92`B6%A8.B!#
M86YN;W0@;W!E;B!L;V<Z("0A(CL*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C
M86-H95]N86UE(#T@)#(["GT*<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]
M("1D:7-T7V-M9'LD,7TI('L*9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN
M:71?:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C
M;60B?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I
M(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I
M;F,["GT*?0II9B`H)&]U="D@>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I
M<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PI]"FUY("1P
M87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF("AD969I;F5D("1P87(I
M('L*;W!E;B!M>2`D9F@L("<\)RP@)'!A<B!O<B!D:64@(D-A;FYO="!F:6YD
M("<D<&%R)SH@)"$B.PIB:6YM;V1E*"1F:"D["F)L97-S*"1F:"P@)TE/.CI&
M:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"`D>FEP+3YR96%D
M1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:
M7T]+*"D@*0IO<B!D:64@(E)E860@)R1P87(G(&5R<F]R.B`D(2(["GT*;7D@
M)65N=B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N
M=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,[
M"B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@
M*"XK*20O;6<["GT*?3L*;&]C86P@)"\@/2!<-#L*:68@*&1E9FEN960@)'!A
M<BD@>PIO<&5N(%!!4BP@)SPG+"`D<&%R(&]R(&1I92`B)"$Z("1P87(B.PIB
M:6YM;V1E*%!!4BD["F1I92`B)'!A<B!I<R!N;W0@82!005(@9FEL92(@=6YL
M97-S(#Q005(^(&5Q(")02UPP,#-<,#`T(CL*?0I#<F5A=&50871H*"1O=70I
M(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?
M0U)%050H*2!\($E/.CI&:6QE.CI/7U=23TY,62@I('P@24\Z.D9I;&4Z.D]?
M5%)53D,H*2P*,#<W-RP**2!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*)"\@
M/2`H9&5F:6YE9"`D9&%T85]P;W,I(#\@7"1D871A7W!O<R`Z('5N9&5F.PIS
M965K(%]&2"P@,"P@,#L*;7D@)&QO861E<B`]('-C86QA<B`\7T9(/CL*:68@
M*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<
M0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z
M.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1L;V%D97(L("0P*0I]
M"F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5E;G8I('L*;7D@)'9A;"`]
M("1E;G9[)&ME>7T@;W(@;F5X=#L*)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L
M(#U^("]>6R<B72\["FUY("1M86=I8R`](")?7T5.5E]005)?(B`N('5C*"1K
M97DI("X@(E]?(CL*;7D@)'-E="`](")005)?(B`N('5C*"1K97DI("X@(CTD
M=F%L(CL*)&QO861E<B`]?B!S>R1M86=I8R@@*RE]>PHD;6%G:6,@+B`D<V5T
M("X@*"<@)R!X("AL96YG=&@H)#$I("T@;&5N9W1H*"1S970I*2D*?65G.PI]
M"B1F:"T^<')I;G0H)&QO861E<BD["B0O(#T@=6YD968["FEF("@D8G5N9&QE
M*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN
M86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@
M0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@
M)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!]
M(&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)
M3D,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ
M9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]
M("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L*;7D@)7=R:71T96X["F9O<F5A
M8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1N86UE+"`D9FEL92D["F9O
M<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&YA;64@/2`D4$%2.CI(96%V
M>3HZ1G5L;$-A8VAE>R1??2D@>PHD9FEL92`]("1?.PIL87-T.PI]"F5L<VEF
M("@O7BA<421D:7)<15PO*"XJ6UY#8UTI*5Q:+VDI('L**"1F:6QE+"`D;F%M
M92D@/2`H)#$L("0R*3L*;&%S=#L*?0IE;'-I9B`H;2%>+VQO861E<B];7B]=
M*R\H+BI;7D-C72E<6B$I('L*:68@*&UY("1R968@/2`D4$%2.CI(96%V>3HZ
M36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q
M*3L*;&%S=#L*?0IE;'-I9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA
M;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T.PI]"GT*?0IN97AT('5N;&5S
M<R!D969I;F5D("1N86UE(&%N9"!N;W0@)'=R:71T96Y[)&YA;65]*RL["FYE
M>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<
M120O.PIO=71S*"!J;VEN("(B+`IQ<2A086-K:6YG("(I+"!R968@)&9I;&4@
M/R`D9FEL92T^>VYA;65](#H@)&9I;&4L"G%Q*"(N+BXI"BD["FUY("1C;VYT
M96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F
M?3L*?0IE;'-E('L*;W!E;B!&24Q%+"`G/"<L("1F:6QE(&]R(&1I92`B0V%N
M)W0@;W!E;B`D9FEL93H@)"$B.PIB:6YM;V1E*$9)3$4I.PHD8V]N=&5N="`]
M(#Q&24Q%/CL*8VQO<V4@1DE,13L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN
M97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4I"FEF("$D14Y6>U!!4E]615)"
M051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&
M:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F
M:6QE+"`D;F%M92D["GT*;W5T<RAQ<2A7<FET=&5N(&%S("(D;F%M92(I*3L*
M)&9H+3YP<FEN="@B1DE,12(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG
M=&@H)&YA;64I("L@.2DI.PHD9F@M/G!R:6YT*'-P<FEN=&8H"B(E,#AX+R5S
M(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M
M90HI*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DI
M.PHD9F@M/G!R:6YT*"1C;VYT96YT*3L*?0I]"B1Z:7`M/G=R:71E5&]&:6QE
M2&%N9&QE*"1F:"D@:68@)'II<#L*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A
M8VAE7VYA;64L(#`L(#0P.PII9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I
M;64@/2`H<W1A="@D;W5T*2E;.5TI('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!
M+3YN97<H,2D["F]P96XH;7D@)&9H+"`B/"(L("1O=70I.PIB:6YM;V1E*"1F
M:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*)&-A8VAE7VYA
M;64@/2`D8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X
M("@T,2`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1C86-H95]N86UE("X](")#
M04-(12(["B1F:"T^<')I;G0H)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*'!A
M8VLH)TXG+"`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI*3L*)&9H+3YP
M<FEN="@D4$%27TU!1TE#*3L*)&9H+3YC;&]S93L*8VAM;V0@,#<U-2P@)&]U
M=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*
M7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN
M:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER
M92!!<F-H:79E.CI::7`["GT*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(",@07)C:&EV93HZ6FEP(&]P97)A
M=&5S(&]N(&%N($E/.CI(86YD;&4*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL
M("=R)RD@;W(@9&EE("(D(3H@)$`B.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK
M4VEZ92@M<R!?1D@I.PIM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B1Z
M:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C
M:&EV93HZ6FEP.CI!6E]/2R@I(&]R(&1I92`B)"$Z("1`(CL*07)C:&EV93HZ
M6FEP.CIS971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#
M86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`[
M"B1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["F]U=',H<7$H7"1%3E9[4$%2
M7U1%35!](#T@(B1%3E9[4$%27U1%35!](BDI.PII9B`H9&5F:6YE9"`D14Y6
M>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*
M9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I
M9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE
M;6)E<BT^9FEL94YA;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M
M>PI>"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PHH
M/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*
M;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ
M4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D[
M"FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP
M<F5S<V5D4VEZ92@I*2!["F]U=',H<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M
M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B*2D[
M"GT@96QS92!["F]U=',H<7$H17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T
M;R`B)&1E<W1?;F%M92(I*3L*)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D
M*"1D97-T7VYA;64I.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@
M97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R
M;V=N86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P
M(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP
M87(@72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@
M<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P
M(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE
M*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE
M+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N
M86UE+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T
M:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D
M:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER
M92!L:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR
M97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S
M.PIR97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@
M17)R;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R
M=&5R.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I
M<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF
M:6<["G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q
M=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E
M<75I<F4@1&EG97-T.CI32$$["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ
M2&5A=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R
M.CI0;V13=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT
M.PIR97%U:7)E(&%T=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE
M=F%L('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z
M.E5T:6P@?3L*979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T
M('T["F5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T[
M"F5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA
M<B!].PIE=F%L('L@<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E
M;7`@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?
M5$5-4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*
M9F]R96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U0
M1$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@
M+W1M<"`N("D**2!["FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD
M("1P871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60[
M"F5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[
M?3L*:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N
M86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W
M=6ED*2!["B1U<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE
M(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*
M?0HD=7-E<FYA;64@/7X@<R]<5R]?+V<["FUY("1S=&UP9&ER(#T@(B1P871H
M)$-O;F9I9WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D[
M"FUK9&ER("1S=&UP9&ER+"`P-S4U.PII9B`H(21%3E9[4$%27T-,14%.?2!A
M;F0@;7D@)&UT:6UE(#T@*'-T870H)'!R;V=N86UE*2E;.5TI('L*;W!E;B`H
M;7D@)&9H+"`B/"(N("1P<F]G;F%M92D["G-E96L@)&9H+"`M,3@L(#(["G-Y
M<W)E860@)&9H+"!M>2`D8G5F+"`V.PII9B`H)&)U9B!E<2`B7#!#04-(12(I
M('L*<V5E:R`D9F@L("TU."P@,CL*<WES<F5A9"`D9F@L("1B=68L(#0Q.PHD
M8G5F(#U^(',O7#`O+V<["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC
M86-H92TB("X@)&)U9CL*?0IE;'-E('L*;7D@)&1I9V5S="`](&5V86P*>PIR
M97%U:7)E($1I9V5S=#HZ4TA!.PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE
M=R@Q*3L*;W!E;BAM>2`D9F@L("(\(BP@)'!R;V=N86UE*3L*8FEN;6]D92@D
M9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["B1C='@M/FAE
M>&1I9V5S=#L*?2`O+R`D;71I;64["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D
M96QI;7UC86-H92TD9&EG97-T(CL*?0IC;&]S92@D9F@I.PI]"F5L<V4@>PHD
M14Y6>U!!4E]#3$5!3GT@/2`Q.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L
M:6U]=&5M<"TD)"(["GT*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;6MD
M:7(@)'-T;7!D:7(L(#`W-34["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@
M)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*
M?0IS=6(@7W1E;7!F:6QE('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E
M*2`]($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL
M97-S("@M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M
M92XD)"(["F]P96X@;7D@)&9H+"`G/B<L("1T96UP;F%M92!O<B!D:64@(F-A
M;B=T('=R:71E("1T96UP;F%M93H@)"$B.PIB:6YM;V1E("1F:#L*<')I;G0@
M)&9H("1C;VYT96YT<SL*8VQO<V4@)&9H.PIC:&UO9"`D;6]D92P@)'1E;7!N
M86UE(&EF(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL
M;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M
M93L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%2
M7U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@
M>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.
M5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-
M4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN
M9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A
M)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I
M9WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O
M9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M
M921#;VYF:6=[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5]
M.PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF
M:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S
M("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD
M9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@
M/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB
M*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D
M0V]N9FEG>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E
M;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E
M;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@
M)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D
M<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]
M("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E
M9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN
M960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I
M.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N
M9FEG>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\["B1%3E9[4$%2
M7U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B![
M"FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N
M.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H
M<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12`I
M("D@>PID96QE=&4@)$5.5GLG4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)
M4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLG4$%27R<N)%]](#T@)$5.
M5GLG4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!
M3%\G+B1??3L*?0IM>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?
M("`@("`@("`@("`@("`@(CL*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T
M92`D14Y6>U!!4E]#3$5!3GT["GT*96QS:68@*"%E>&ES=',@)$5.5GM005)?
M1TQ/0D%,7T-,14%.?2D@>PIM>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A
M;BP@,3(@*R!L96YG=&@H(D-,14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D
M,2!I9B`D=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U
M=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L
M;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I
M;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F
M:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP
M('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H
M97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!0
M05(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R
M="A`<&%R7V%R9W,I.PID:64@<7$H<&%R+G!L.B!#86XG="!O<&5N('!E<FP@
M<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y
M7&XI"G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ
M97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE
M("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ
M97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<
M*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?
M"@``````````7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("``````
M`````'!E<FQX<VDN8P````$;`SL0`````0```%2#__\L````%``````````!
M>E(``7P!`1P-`P``````&````!P````@@________X0```````````<!````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````,`E````````8"4`
M```````!``````````$``````````0````````"M`0````````$`````````
MN`$````````!`````````,(!`````````0`````````1`@````````$`````
M````70,````````!`````````'<#````````&0````````"@_0```````!L`
M````````"``````````:`````````*C]````````'``````````(````````
M``0`````````D`(```````#U_O]O`````,@%````````!0````````"0$```
M``````8`````````H`8````````*`````````-\$````````"P`````````8
M`````````!4````````````````````#`````````!```0```````@``````
M``"(!0```````!0`````````!P`````````7`````````+`8````````!P``
M``````"X%@````````@`````````@`<````````)`````````!@`````````
M'@`````````(`````````/O__V\``````0``"`````#^__]O`````$@6````
M````____;P`````#`````````/#__V\`````<!4```````#Y__]O``````<`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````_____P````!X9@```````/__________``````````!`
M'@```````$`>````````0!X```````!`'@```````$`>````````0!X`````
M``!`'@```````$`>````````0!X```````!`'@```````$`>````````0!X`
M``````!`'@```````$`>````````0!X```````!`'@```````$`>````````
M0!X```````!`'@```````$`>````````0!X```````!`'@```````$`>````
M````0!X```````!`'@```````$`>````````0!X```````!`'@```````$`>
M````````0!X```````!`'@```````$`>````````0!X```````!`'@``````
M`$`>````````0!X```````!`'@```````$`>````````0!X```````!`'@``
M`````$`>````````0!X```````!`'@```````$`>````````0!X```````!`
M'@```````$`>````````0!X```````!`'@```````$`>````````0!X`````
M``!`'@```````$`>````````0!X```````!`'@```````$`>````````0!X`
M``````!`'@```````$`>````````L/T``````````````````(!B````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````Z&$`````````````````````
M```````````````````0(@```````(`"`0``````1T-#.B`H1&5B:6%N(#@N
M,RXP+38N;&YD+C$I(#@N,RXP```N<VAS=')T86(`+FEN=&5R<``N;F]T92Y!
M0DDM=&%G`"YN;W1E+F=N=2YB=6EL9"UI9``N9VYU+FAA<V@`+F1Y;G-Y;0`N
M9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L82YD>6X`
M+G)E;&$N<&QT`"YT97AT`"YR;V1A=&$`+F5H7V9R86UE7VAD<@`N96A?9G)A
M;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`+F1Y;F%M:6,`+F1A=&$`+F=O
M=``N<V1A=&$`+F)S<P`N8V]M;65N=```````````````````````````````
M``````````````````````````````````````````````````````````L`
M```!`````@`````````X`@```````#@"````````#P``````````````````
M``$````````````````````3````!P````(`````````2`(```````!(`@``
M`````"`````````````````````$````````````````````(0````<````"
M`````````&@"````````:`(````````D````````````````````!```````
M`````````````#@````%`````@````````"0`@```````)`"````````-`,`
M```````&``````````@`````````!``````````T````]O__;P(`````````
MR`4```````#(!0```````-@`````````!@`````````(````````````````
M````/@````L````"`````````*`&````````H`8```````#P"0````````<`
M```'````"``````````8`````````$8````#`````@````````"0$```````
M`)`0````````WP0```````````````````$```````````````````!.````
M____;P(`````````<!4```````!P%0```````-0`````````!@`````````"
M``````````(`````````6P```/[__V\"`````````$@6````````2!8`````
M``!P``````````<````#````"````````````````````&H````$`````@``
M``````"X%@```````+@6````````^`$````````&``````````@`````````
M&`````````!T````!````$(`````````L!@```````"P&````````(@%````
M````!@```!4````(`````````!@`````````>0````$````&`````````$`>
M````````0!X```````#0`P``````````````````$``````````0````````
M`'X````!````!@`````````0(@```````!`B````````D$``````````````
M``````@```````````````````"$`````0````(`````````H&(```````"@
M8@```````'(^```````````````````(````````````````````C`````$`
M```"`````````!2A````````%*$````````4````````````````````!```
M`````````````````)H````!`````@`````````HH0```````"BA````````
M.`````````````````````@```````````````````"D````#@````,`````
M````H/T```````"@O0````````@````````````````````(``````````@`
M````````L`````\````#`````````*C]````````J+T````````(````````
M````````````"``````````(`````````+P````&`````P````````"P_0``
M`````+"]````````4`(````````'``````````@`````````$`````````#%
M`````0````,````````````!````````P````````!``````````````````
M```(````````````````````RP````$````#`````````!```0``````$,``
M``````!P`@``````````````````"``````````(`````````-`````!````
M`P````````"``@$``````(#"````````"`````````````````````@`````
M``````````````#7````"`````,`````````B`(!``````"(P@```````#`0
M```````````````````(````````````````````W`````$````P````````
M````````````B,(````````B`````````````````````0`````````!````
M``````$````#`````````````````````````*K"````````Y0``````````
7``````````$`````````````````````
